bridge

package
v0.0.0-...-8ec1dd0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 1, 2018 License: GPL-3.0 Imports: 4 Imported by: 0

Documentation

Overview

Package bridge contains the high-level public functions to use and manage bridges

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ConfiguredBridges

func ConfiguredBridges(repo repository.RepoCommon) ([]string, error)

ConfiguredBridges return the list of bridge that are configured for the given repo

func DefaultBridge

func DefaultBridge(repo *cache.RepoCache) (*core.Bridge, error)

Attempt to retrieve a default bridge for the given repo. If zero or multiple bridge exist, it fails.

func NewBridge

func NewBridge(repo *cache.RepoCache, target string, name string) (*core.Bridge, error)

Instantiate a new Bridge for a repo, from the given target and name

func NewBridgeFullName

func NewBridgeFullName(repo *cache.RepoCache, fullName string) (*core.Bridge, error)

Instantiate a new bridge for a repo, from the combined target and name contained in the full name

func RemoveBridges

func RemoveBridges(repo repository.RepoCommon, fullName string) error

Remove a configured bridge

func Targets

func Targets() []string

Targets return all known bridge implementation target

Types

This section is empty.

Directories

Path Synopsis
Package core contains the target-agnostic code to define and run a bridge
Package core contains the target-agnostic code to define and run a bridge
Package github contains the Github bridge implementation
Package github contains the Github bridge implementation

Jump to