Documentation
¶
Overview ¶
Package bridge contains the high-level public functions to use and manage bridges
Index ¶
- func ConfiguredBridges(repo repository.RepoCommon) ([]string, error)
- func DefaultBridge(repo *cache.RepoCache) (*core.Bridge, error)
- func NewBridge(repo *cache.RepoCache, target string, name string) (*core.Bridge, error)
- func NewBridgeFullName(repo *cache.RepoCache, fullName string) (*core.Bridge, error)
- func RemoveBridges(repo repository.RepoCommon, fullName string) error
- func Targets() []string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ConfiguredBridges ¶
func ConfiguredBridges(repo repository.RepoCommon) ([]string, error)
ConfiguredBridges return the list of bridge that are configured for the given repo
func DefaultBridge ¶
Attempt to retrieve a default bridge for the given repo. If zero or multiple bridge exist, it fails.
func NewBridgeFullName ¶
Instantiate a new bridge for a repo, from the combined target and name contained in the full name
func RemoveBridges ¶
func RemoveBridges(repo repository.RepoCommon, fullName string) error
Remove a configured bridge
Types ¶
This section is empty.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package core contains the target-agnostic code to define and run a bridge
|
Package core contains the target-agnostic code to define and run a bridge |
|
Package github contains the Github bridge implementation
|
Package github contains the Github bridge implementation |
Click to show internal directories.
Click to hide internal directories.